import { BigDecimal } from '@vertex-protocol/utils';
/**
 * Representation of the ProductEngineType enum used within the contract
 * Enums do not get reflected in the ABI, so this must be manually defined
 */
export declare enum ProductEngineType {
    SPOT = 0,
    PERP = 1
}
/**
 * Maps a raw ProductEngineType enum value to the proper type
 * @param val
 */
export declare function toProductEngineType(val: number): ProductEngineType;
/**
 * Shared properties across products
 */
interface BaseProduct {
    type: ProductEngineType;
    productId: number;
    oraclePrice: BigDecimal;
    longWeightInitial: BigDecimal;
    shortWeightInitial: BigDecimal;
    longWeightMaintenance: BigDecimal;
    shortWeightMaintenance: BigDecimal;
    totalLpQuoteAmount: BigDecimal;
    totalLpBaseAmount: BigDecimal;
    totalLpSupply: BigDecimal;
}
/**
 * Represents a product stored in PerpEngine
 */
export interface PerpProduct extends BaseProduct {
    type: ProductEngineType.PERP;
    openInterest: BigDecimal;
    cumulativeFundingLong: BigDecimal;
    cumulativeFundingShort: BigDecimal;
}
/**
 * Represents a product stored in SpotEngine.
 *
 * @see {@link calcBorrowRatePerSecond} for more details on the calculation and interest parameters
 */
export interface SpotProduct extends BaseProduct {
    type: ProductEngineType.SPOT;
    tokenAddr: string;
    interestFloor: BigDecimal;
    interestInflectionUtil: BigDecimal;
    interestSmallCap: BigDecimal;
    interestLargeCap: BigDecimal;
    totalDeposited: BigDecimal;
    totalBorrowed: BigDecimal;
}
export type Product = PerpProduct | SpotProduct;
export {};
//# sourceMappingURL=productTypes.d.ts.map