import { toBigInt } from '@vertex-protocol/utils';
import { toHex } from 'viem';
import { subaccountNameToBytes12 } from '../utils';
/**
 * Deposits collateral through the Endpoint contract, which will be picked up automatically by the sequencer and
 * submitted.
 *
 */
export async function depositCollateral({ endpoint, subaccountName, productId, amount, referralCode, }) {
    const subaccountNameHex = toHex(subaccountNameToBytes12(subaccountName));
    if (referralCode) {
        return endpoint.write.depositCollateralWithReferral([
            // bytes12
            subaccountNameHex,
            // uint32
            productId,
            // uint128
            toBigInt(amount),
            // string
            referralCode,
        ]);
    }
    else {
        return endpoint.write.depositCollateral([
            subaccountNameHex,
            productId,
            toBigInt(amount),
        ]);
    }
}
//# sourceMappingURL=depositCollateral.js.map